@@ -1,4 +1,4 @@
-from ctypes import c_int, c_char_p, c_void_p, CFUNCTYPE
+from ctypes import c_int, c_uint, c_char_p, c_void_p, CFUNCTYPE
 
 from ..lib import lib
 
@@ -14,12 +14,15 @@ HttpRouteAuthType = c_int
 
 HTTP_ROUTE_AUTH_TYPE_NONE = 0
 HTTP_ROUTE_AUTH_TYPE_BEARER = 1
+HTTP_ROUTE_AUTH_TYPE_CUSTOM = 2
 
 HttpHandler = CFUNCTYPE (None, c_void_p, c_void_p)
 
 HttpDecodeData = CFUNCTYPE (c_void_p, c_void_p)
 HttpDeleteDecoded = CFUNCTYPE (None, c_void_p)
 
+AuthenticationHandler = CFUNCTYPE (c_uint, c_void_p, c_void_p)
+
 http_route_create = lib.http_route_create
 http_route_create.argtypes = [RequestMethod, c_char_p, HttpHandler]
 http_route_create.restype = c_void_p
@@ -41,3 +44,6 @@ http_route_set_decode_data.argtypes = [c_void_p, HttpDecodeData, HttpDeleteDecod
 
 http_route_set_decode_data_into_json = lib.http_route_set_decode_data_into_json
 http_route_set_decode_data_into_json.argtypes = [c_void_p]
+
+http_route_set_authentication_handler = lib.http_route_set_authentication_handler
+http_route_set_authentication_handler.argtypes = [c_void_p, AuthenticationHandler]
